==> php-residence_0.2.4.tar.gz: php-residence/tabella2.php <==
<html>
<header>
<title> </title>
</header>
<body bgcolor=#ffffff>

<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#################################################################################

$pag = "tabella2.php";

include ("dati/connessione_db.php");
include ("includes/funzioni.php");
$tablenometariffe = ntariffe . $anno;
$tableprenota = prenota .$anno;
$tableperiodi = periodi . $anno;

$oggi = date("j/n/Y");
$ora = date("H:i");
echo "<font size=-2>".mex("situazione alle",$pag)." $ora ".mex("del",$pag)." $oggi</font><br>";

if ($anno_succ == "SI") { $mese = $mese + 12; }

$data_inizio_periodi = pg_exec("select * from $tableperiodi where idperiodi = 1");
$data_inizio_periodi = pg_result($data_inizio_periodi,0,datainizio);
$data_inizio_periodi = explode("-",$data_inizio_periodi);
$mese_inizio_periodi = $data_inizio_periodi[1];
if ($mese < $mese_inizio_periodi) { $mese = $mese_inizio_periodi; }
$data_fine_periodi = pg_exec("select max(idperiodi) from $tableperiodi");
$data_fine_periodi = pg_result($data_fine_periodi,0,max);
$data_fine_periodi = pg_exec("select * from $tableperiodi where idperiodi = $data_fine_periodi");
$data_fine_periodi = pg_result($data_fine_periodi,0,datainizio);
$data_fine_periodi = explode("-",$data_fine_periodi);
$mese_fine_periodi = $data_fine_periodi[1] + (($data_fine_periodi[2] - $anno) * 12);
if ($mese > $mese_fine_periodi) { $mese = $mese_fine_periodi; }

$appartamenti = pg_exec("select * from appartamenti order by idappartamenti");
$num_appartamenti = pg_numrows($appartamenti);

$num_righe_app_max = pg_exec("select valpersonalizza_num from personalizza where idpersonalizza = 'num_linee_tab2_prenota'");
$num_righe_app_max = pg_result($num_righe_app_max,0,valpersonalizza_num);
$num_tabelle = floor($num_righe_app_max/$num_appartamenti);
$mese_ini_for = $mese;
$mese_fine_for = $mese;
$mese_da_aggiungere = "dopo";
for ($num1 = 2 ; $num1 <= $num_tabelle ; $num1++) {
if ($mese_fine_for >= $mese_fine_periodi) $mese_da_aggiungere = "prima";
if ($mese_da_aggiungere == "prima") {
if ($mese_ini_for <= $mese_inizio_periodi) $mese_da_aggiungere = "dopo";
else $mese_ini_for--;
} # fine if ($mese_da_aggiungere == "prima")
if ($mese_da_aggiungere == "dopo" and $mese_fine_for < $mese_fine_periodi) $mese_fine_for++;
if ($mese_da_aggiungere == "prima") $mese_da_aggiungere = "dopo";
else $mese_da_aggiungere = "prima";
} # fine for $num1

if ($tutti_mesi) {
$mese_ini_for = $mese_inizio_periodi;
$mese_fine_for = $mese_fine_periodi;
} # fine if ($tutti_mesi)

for ($mese2 = $mese_ini_for ; $mese2 <= $mese_fine_for ; $mese2 = $mese2 + 1) {

if ($mese2 == 25) {
$mese_mostra = 1;
$anno_mostra = $anno + 2;
} # fine if ($mese == 25)
else {
if ($mese2 > 12) {
$mese_mostra = $mese2 - 12;
$anno_mostra = $anno + 1;
} # fine if ($mese > 12)
else {
$mese_mostra = $mese2;
$anno_mostra = $anno;
} # fine else if ($mese > 12)
} # fine else if ($mese == 25)

$aggiunta_tronca = pg_exec("select valpersonalizza_num from personalizza where idpersonalizza = 'aggiunta_tronca_nomi_tab1'");
$aggiunta_tronca = pg_result($aggiunta_tronca,0,valpersonalizza_num);

echo "<center><font size=-1><b>".mex("Tabella prenotazioni del",$pag)." $mese_mostra-$anno_mostra.</b></font></center>
<table border=1 cellspacing=0 cellpadding=1 align=\"center\">";
$mese_inizio_tab = $mese2;
$data_inizio_tab = date("M d, Y" , mktime(0,0,0,$mese_inizio_tab,1,$anno));
$data_inizio_tab = pg_exec("select * from $tableperiodi where datainizio >= '$data_inizio_tab' order by idperiodi");
$id_data_inizio_tab = pg_result($data_inizio_tab,0,idperiodi);
if ($mese2 != $mese_inizio_periodi) {
$g_inizio_tab = pg_result($data_inizio_tab,0,datainizio);
$g_inizio_tab = explode("-",$g_inizio_tab);
$g_inizio_tab = $g_inizio_tab[0];
if ($g_inizio_tab == 7 or $g_inizio_tab == 6) { $id_data_inizio_tab = $id_data_inizio_tab - 1; }
} # fine else if ($mese2 != $mese_inizio_periodi)
$mese_fine_tab = $mese2;
$data_fine_tab = date("M d, Y" , mktime(0,0,0,$mese_fine_tab,31,$anno));
$data_fine_tab = pg_exec("select * from $tableperiodi where datainizio <= '$data_fine_tab' order by idperiodi");
$num_date = pg_numrows($data_fine_tab);
$num_date = $num_date - 1;
$id_data_fine_tab = pg_result($data_fine_tab,$num_date,idperiodi);
$g_fine_tab = pg_result($data_fine_tab,$num_date,datafine);
$g_fine_tab = explode("-",$g_fine_tab);
$g_fine_tab = $g_fine_tab[0];
if ($g_fine_tab == 8 or $g_fine_tab == 9 or $g_fine_tab == 10) { $id_data_fine_tab = $id_data_fine_tab - 1; }
if ($mese2 != $mese_fine_periodi) {
if ($g_fine_tab == 7 or $g_fine_tab == 6) { $id_data_fine_tab = $id_data_fine_tab - 1; }
} # fine else if ($mese2 != $mese_fine_periodi)
$num_colonne = $id_data_fine_tab - $id_data_inizio_tab + 1;

# controllo se vi sono prenotazioni in appartamenti cancellati
$num_appartamenti_cancellati = 0;
$query_prenota_app_canc = "select * from $tableprenota where iddatainizio <= $id_data_fine_tab and iddatafine >= $id_data_inizio_tab";
for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
$id_appartamento = pg_result($appartamenti,$num1,idappartamenti);
$query_prenota_app_canc .= " and idappartamenti != '$id_appartamento'";
} # fine for $num1
$prenota_app_canc = pg_exec($query_prenota_app_canc);
$num_prenota_app_canc = pg_numrows($prenota_app_canc);
$num_app_canc = 0;
for ($num1 = 0 ; $num1 < $num_prenota_app_canc; $num1 = $num1 + 1) {
$idapp_prenota_app_canc = pg_result($prenota_app_canc,$num1,idappartamenti);
if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI") {
$app_canc_trovato[$idapp_prenota_app_canc] = "SI";
$app_canc[$num_app_canc] = $idapp_prenota_app_canc;
$num_app_canc++;
} # fine if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI")
} # fine for $num1

echo "<tr><td>&nbsp;</td>
";
for ($num1 = 0 ; $num1 < $num_colonne ; $num1 = $num1 + 1) {
$id_settimana = $id_data_inizio_tab + $num1;
$riga_setimana = pg_exec("select * from $tableperiodi where idperiodi = $id_settimana");
$inizio_settimana = pg_result($riga_setimana,0,datainizio);
$inizio_settimana = explode("-",$inizio_settimana);
$g_inizio_settimana = $inizio_settimana[0];
$m_inizio_settimana = $inizio_settimana[1];
$fine_settimana = pg_result($riga_setimana,0,datafine);
$fine_settimana = explode("-",$fine_settimana);
$g_fine_settimana = $fine_settimana[0];
$m_fine_settimana = $fine_settimana[1];
for ($num2 = 0 ; $num2 < 8 ; $num2 = $num2 + 1) {
$num_giorno = $g_fine_settimana - 7 + $num2;
if ($num_giorno < 1) { $num_giorno = $g_inizio_settimana + $num2; }
if ($num2 != 7 or $num1 == ($num_colonne - 1)) {
echo "<td align=\"center\"";
if ($num2 == 0 or $num2 == 7) {
echo " bgcolor=\"#cccccc\"";
if ($num1 != 0 and $num2 != 7) { echo " colspan=\"2\""; }
} # fine if ($num2 == 0)
$lunghezza = strlen ($num_giorno);
if ($lunghezza == 1) { $num_giorno = "0".$num_giorno; }
echo "><font size=-2>$num_giorno</font></td>
";
} # fine if ($num2 != 7 or $num1 == ($num_colonne - 1))
} # fine for $num2
} # fine for $num1
echo "<td>&nbsp;</td></tr>";

for ($num1 = 0 ; $num1 < ($num_appartamenti + $num_app_canc) ; $num1 = $num1 + 1) {
if ($num1 < $num_appartamenti) {
$id_appartamento = pg_result($appartamenti,$num1,idappartamenti);
echo "<tr><td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
else echo "<font size=-1>";
echo "$id_appartamento</font></td>";
} # fine if ($num1 < $num_appartamenti)
else {
$id_appartamento = $app_canc[($num1 - $num_appartamenti)];
echo "<tr><td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
else echo "<font size=-1>";
echo "<font color=\"red\">$id_appartamento</font></font></td>";
} # fine else if ($num1 < $num_appartamenti)

for ($num2 = 0 ; $num2 < $num_colonne ; $num2 = $num2 + 1) {
$id_settimana = $id_data_inizio_tab + $num2;
$prenotazione_presente = pg_exec("select * from $tableprenota where idappartamenti = '$id_appartamento' and iddatainizio <= $id_settimana and iddatafine >= $id_settimana");
$esiste = pg_numrows($prenotazione_presente);
if ($esiste == 1) {
$id_prenota = pg_result($prenotazione_presente,0,idprenota);
$id_clienti = pg_result($prenotazione_presente,0,idclienti);
$cognome = pg_exec("select * from clienti where idclienti = $id_clienti");
$cognome = pg_result($cognome,0,cognome);

$colore = "";
$pagato = pg_result($prenotazione_presente,0,pagato);
if (!$pagato) { $pagato = 0; }
$caparra = pg_result($prenotazione_presente,0,caparra);
if (!$caparra) { $caparra = 0; }
$costo_tot = pg_result($prenotazione_presente,0,tariffa_tot);
if ($pagato < $caparra) { $colore = "#CC0000"; }
else { if ($pagato < $costo_tot) { $colore = "#FFCC00"; } }

$id_inizio_prenota = pg_result($prenotazione_presente,0,iddatainizio);
$id_fine_prenota = pg_result($prenotazione_presente,0,iddatafine);
if ($id_inizio_prenota > $id_data_inizio_tab) { $id_inizio = $id_inizio_prenota; }
else { $id_inizio = $id_data_inizio_tab; }
if ($id_fine_prenota < $id_data_fine_tab) { $id_fine = $id_fine_prenota; }
else { $id_fine = $id_data_fine_tab; }
$colonne = $id_fine - $id_inizio + 1;
$riduci_font = "";
$lung_cognome = strlen($cognome);
$lung_freccia = 0;
if ($id_fine_prenota > $id_data_fine_tab or $id_inizio_prenota < $id_data_inizio_tab) $lung_freccia = 3;
$lung_non_ridotta = (12+$aggiunta_tronca)*$colonne - $lung_freccia;
if ($lung_cognome > $lung_non_ridotta) $riduci_font = "SI";
$lung_non_tronca = (15+$aggiunta_tronca)*$colonne;
if ($lung_freccia == 3) $lung_non_tronca = $lung_non_tronca - 1;
if ($lung_cognome > ($lung_non_tronca+1)) $cognome = substr($cognome,0,$lung_non_tronca).".";
echo "<td";
#if ($colore) { echo " bgcolor =\"$colore\""; }
$colonne_span = $colonne * 8;
echo" align=\"center\" colspan=\"$colonne_span\">";
if ($id_inizio_prenota < $id_data_inizio_tab) { echo "<- "; }
echo "<font size=-2>
<a href=\"modifica_prenota.php?id_prenota=$id_prenota&anno=$anno&mese=$mese\">$cognome</a>
</font>";
if ($id_fine_prenota > $id_data_fine_tab) { echo " ->"; }
echo "</td>
";
$num2 = $num2 + $colonne - 1;
} # fine if ($esiste == 1)
else {
for ($num3 = 0 ; $num3 < 8 ; $num3 = $num3 + 1) {
echo "<td";
if ($num3 == 0 or $num3 == 7) { echo " bgcolor =\"#cccccc\""; }
echo ">&nbsp;</td>
";
} # fine for $num3
} # fine else if ($esiste == 1)
} # fine for $num2

if ($num1 < $num_appartamenti) {
echo "<td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
else echo "<font size=-1>";
echo "$id_appartamento</font></td>";
} # fine if ($num1 < $num_appartamenti)
else {
echo "<td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
else echo "<font size=-1>";
echo "<font color=\"red\">$id_appartamento</font></font></td>";
} # fine else if ($num1 < $num_appartamenti)
echo "</tr>";

} # fine for $num1

echo "</table>";

} # fine for $mese2


echo "<center>
<form method=\"post\" action=\"inizio.php\">";
if ($mese != 1) {
$mese_prec = $mese - 1;
echo "<a href=\"tabella2.php?anno=$anno&mese=$mese_prec\"><--</a>&nbsp;&nbsp;&nbsp;&nbsp;";
} # fine if ($mese != 1)
echo "<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"".mex("Torna al men principale",$pag)."\">";
if ($mese != 25) {
$mese_succ = $mese + 1;
echo "&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"tabella2.php?anno=$anno&mese=$mese_succ\">--></a>";
} # fine if ($mese != 12)
echo "</form>
<form method=\"post\" action=\"tabella.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"mese\" value=\"$mese\">
<input type=\"submit\" name=\"tab2\" value=\"".mex("Visualizza la tabella normale",$pag)."\">
</form>
<form method=\"post\" action=\"tabella2.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"mese\" value=\"$mese\">
<input type=\"submit\" name=\"tutti_mesi\" value=\"".mex("Visualizza tutti i mesi",$pag)."\">
</form></center>";



?>

</body>
</html>

==> php-residence_0.3.tar.gz: php-residence/tabella2.php <==
<html>
<header>
<title> </title>
</header>
<body bgcolor=#ffffff>

<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#################################################################################

$pag = "tabella2.php";

include("./dati/dati_connessione.php");
include("./includes/funzioni_$PHPR_DB_TYPE.php");
connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
include ("./includes/funzioni.php");
$tablenometariffe = ntariffe . $anno;
$tableprenota = prenota .$anno;
$tableperiodi = periodi . $anno;

#$tabelle_lock = array("$tableprenota");
$altre_tab_lock = array("$tableprenota","$tableperiodi","appartamenti","clienti");
$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);

$oggi = date("j/n/Y");
$ora = date("H:i");
echo "<font size=-2>".mex("situazione alle",$pag)." $ora ".mex("del",$pag)." $oggi</font><br>";

if ($anno_succ == "SI") { $mese = $mese + 12; }

$data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
$data_inizio_periodi = risul_query($data_inizio_periodi,0,datainizio);
$data_inizio_periodi = explode("-",$data_inizio_periodi);
$mese_inizio_periodi = $data_inizio_periodi[1];
if ($mese < $mese_inizio_periodi) { $mese = $mese_inizio_periodi; }
$data_fine_periodi = esegui_query("select max(idperiodi) from $tableperiodi");
$data_fine_periodi = risul_query($data_fine_periodi,0,0);
$data_fine_periodi = esegui_query("select * from $tableperiodi where idperiodi = $data_fine_periodi");
$data_fine_periodi = risul_query($data_fine_periodi,0,datainizio);
$data_fine_periodi = explode("-",$data_fine_periodi);
$mese_fine_periodi = $data_fine_periodi[1] + (($data_fine_periodi[0] - $anno) * 12);
if ($mese > $mese_fine_periodi) { $mese = $mese_fine_periodi; }

$appartamenti = esegui_query("select * from appartamenti order by idappartamenti");
$num_appartamenti = numlin_query($appartamenti);

$num_righe_app_max = esegui_query("select valpersonalizza_num from personalizza where idpersonalizza = 'num_linee_tab2_prenota'");
$num_righe_app_max = risul_query($num_righe_app_max,0,valpersonalizza_num);
$num_tabelle = floor($num_righe_app_max/$num_appartamenti);
$mese_ini_for = $mese;
$mese_fine_for = $mese;
$mese_da_aggiungere = "dopo";
for ($num1 = 2 ; $num1 <= $num_tabelle ; $num1++) {
if ($mese_fine_for >= $mese_fine_periodi) $mese_da_aggiungere = "prima";
if ($mese_da_aggiungere == "prima") {
if ($mese_ini_for <= $mese_inizio_periodi) $mese_da_aggiungere = "dopo";
else $mese_ini_for--;
} # fine if ($mese_da_aggiungere == "prima")
if ($mese_da_aggiungere == "dopo" and $mese_fine_for < $mese_fine_periodi) $mese_fine_for++;
if ($mese_da_aggiungere == "prima") $mese_da_aggiungere = "dopo";
else $mese_da_aggiungere = "prima";
} # fine for $num1

if ($tutti_mesi) {
$mese_ini_for = $mese_inizio_periodi;
$mese_fine_for = $mese_fine_periodi;
} # fine if ($tutti_mesi)

for ($mese2 = $mese_ini_for ; $mese2 <= $mese_fine_for ; $mese2 = $mese2 + 1) {

if ($mese2 == 25) {
$mese_mostra = 1;
$anno_mostra = $anno + 2;
} # fine if ($mese == 25)
else {
if ($mese2 > 12) {
$mese_mostra = $mese2 - 12;
$anno_mostra = $anno + 1;
} # fine if ($mese > 12)
else {
$mese_mostra = $mese2;
$anno_mostra = $anno;
} # fine else if ($mese > 12)
} # fine else if ($mese == 25)

$aggiunta_tronca = esegui_query("select valpersonalizza_num from personalizza where idpersonalizza = 'aggiunta_tronca_nomi_tab1'");
$aggiunta_tronca = risul_query($aggiunta_tronca,0,valpersonalizza_num);

echo "<center><font size=-1><b>".mex("Tabella prenotazioni del",$pag)." $mese_mostra-$anno_mostra.</b></font></center>
<table border=1 cellspacing=0 cellpadding=1 align=\"center\">";
$mese_inizio_tab = $mese2;
$data_inizio_tab = date("Y-m-d" , mktime(0,0,0,$mese_inizio_tab,1,$anno));
$data_inizio_tab = esegui_query("select * from $tableperiodi where datainizio >= '$data_inizio_tab' order by idperiodi");
$id_data_inizio_tab = risul_query($data_inizio_tab,0,idperiodi);
if ($mese2 != $mese_inizio_periodi) {
$g_inizio_tab = risul_query($data_inizio_tab,0,datainizio);
$g_inizio_tab = explode("-",$g_inizio_tab);
$g_inizio_tab = $g_inizio_tab[2];
if ($g_inizio_tab == 7 or $g_inizio_tab == 6) { $id_data_inizio_tab = $id_data_inizio_tab - 1; }
} # fine else if ($mese2 != $mese_inizio_periodi)
$mese_fine_tab = $mese2;
$data_fine_tab = date("Y-m-d" , mktime(0,0,0,$mese_fine_tab,31,$anno));
$data_fine_tab = esegui_query("select * from $tableperiodi where datainizio <= '$data_fine_tab' order by idperiodi");
$num_date = numlin_query($data_fine_tab);
$num_date = $num_date - 1;
$id_data_fine_tab = risul_query($data_fine_tab,$num_date,idperiodi);
$g_fine_tab = risul_query($data_fine_tab,$num_date,datafine);
$g_fine_tab = explode("-",$g_fine_tab);
$g_fine_tab = $g_fine_tab[2];
if ($g_fine_tab == 8 or $g_fine_tab == 9 or $g_fine_tab == 10) { $id_data_fine_tab = $id_data_fine_tab - 1; }
if ($mese2 != $mese_fine_periodi) {
if ($g_fine_tab == 7 or $g_fine_tab == 6) { $id_data_fine_tab = $id_data_fine_tab - 1; }
} # fine else if ($mese2 != $mese_fine_periodi)
$num_colonne = $id_data_fine_tab - $id_data_inizio_tab + 1;

# controllo se vi sono prenotazioni in appartamenti cancellati
$num_appartamenti_cancellati = 0;
$query_prenota_app_canc = "select * from $tableprenota where iddatainizio <= $id_data_fine_tab and iddatafine >= $id_data_inizio_tab";
for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
$id_appartamento = risul_query($appartamenti,$num1,idappartamenti);
$query_prenota_app_canc .= " and idappartamenti != '$id_appartamento'";
} # fine for $num1
$prenota_app_canc = esegui_query($query_prenota_app_canc);
$num_prenota_app_canc = numlin_query($prenota_app_canc);
$num_app_canc = 0;
for ($num1 = 0 ; $num1 < $num_prenota_app_canc; $num1 = $num1 + 1) {
$idapp_prenota_app_canc = risul_query($prenota_app_canc,$num1,idappartamenti);
if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI") {
$app_canc_trovato[$idapp_prenota_app_canc] = "SI";
$app_canc[$num_app_canc] = $idapp_prenota_app_canc;
$num_app_canc++;
} # fine if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI")
} # fine for $num1

echo "<tr><td>&nbsp;</td>
";
for ($num1 = 0 ; $num1 < $num_colonne ; $num1 = $num1 + 1) {
$id_settimana = $id_data_inizio_tab + $num1;
$riga_setimana = esegui_query("select * from $tableperiodi where idperiodi = $id_settimana");
$inizio_settimana = risul_query($riga_setimana,0,datainizio);
$inizio_settimana = explode("-",$inizio_settimana);
$g_inizio_settimana = $inizio_settimana[2];
$m_inizio_settimana = $inizio_settimana[1];
$fine_settimana = risul_query($riga_setimana,0,datafine);
$fine_settimana = explode("-",$fine_settimana);
$g_fine_settimana = $fine_settimana[2];
$m_fine_settimana = $fine_settimana[1];
for ($num2 = 0 ; $num2 < 8 ; $num2 = $num2 + 1) {
$num_giorno = $g_fine_settimana - 7 + $num2;
if ($num_giorno < 1) { $num_giorno = $g_inizio_settimana + $num2; }
if ($num2 != 7 or $num1 == ($num_colonne - 1)) {
echo "<td align=\"center\"";
if ($num2 == 0 or $num2 == 7) {
echo " bgcolor=\"#cccccc\"";
if ($num1 != 0 and $num2 != 7) { echo " colspan=\"2\""; }
} # fine if ($num2 == 0)
$lunghezza = strlen ($num_giorno);
if ($lunghezza == 1) { $num_giorno = "0".$num_giorno; }
echo "><font size=-2>$num_giorno</font></td>
";
} # fine if ($num2 != 7 or $num1 == ($num_colonne - 1))
} # fine for $num2
} # fine for $num1
echo "<td>&nbsp;</td></tr>";

for ($num1 = 0 ; $num1 < ($num_appartamenti + $num_app_canc) ; $num1 = $num1 + 1) {
if ($num1 < $num_appartamenti) {
$id_appartamento = risul_query($appartamenti,$num1,idappartamenti);
echo "<tr><td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
else echo "<font size=-1>";
echo "$id_appartamento</font></td>";
} # fine if ($num1 < $num_appartamenti)
else {
$id_appartamento = $app_canc[($num1 - $num_appartamenti)];
echo "<tr><td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
else echo "<font size=-1>";
echo "<font color=\"red\">$id_appartamento</font></font></td>";
} # fine else if ($num1 < $num_appartamenti)

for ($num2 = 0 ; $num2 < $num_colonne ; $num2 = $num2 + 1) {
$id_settimana = $id_data_inizio_tab + $num2;
$prenotazione_presente = esegui_query("select * from $tableprenota where idappartamenti = '$id_appartamento' and iddatainizio <= $id_settimana and iddatafine >= $id_settimana");
$esiste = numlin_query($prenotazione_presente);
if ($esiste == 1) {
$id_prenota = risul_query($prenotazione_presente,0,idprenota);
$id_clienti = risul_query($prenotazione_presente,0,idclienti);
$cognome = esegui_query("select * from clienti where idclienti = $id_clienti");
$cognome = risul_query($cognome,0,cognome);

$colore = "";
$pagato = risul_query($prenotazione_presente,0,pagato);
if (!$pagato) { $pagato = 0; }
$caparra = risul_query($prenotazione_presente,0,caparra);
if (!$caparra) { $caparra = 0; }
$costo_tot = risul_query($prenotazione_presente,0,tariffa_tot);
if ($pagato < $caparra) { $colore = "#CC0000"; }
else { if ($pagato < $costo_tot) { $colore = "#FFCC00"; } }

$id_inizio_prenota = risul_query($prenotazione_presente,0,iddatainizio);
$id_fine_prenota = risul_query($prenotazione_presente,0,iddatafine);
if ($id_inizio_prenota > $id_data_inizio_tab) { $id_inizio = $id_inizio_prenota; }
else { $id_inizio = $id_data_inizio_tab; }
if ($id_fine_prenota < $id_data_fine_tab) { $id_fine = $id_fine_prenota; }
else { $id_fine = $id_data_fine_tab; }
$colonne = $id_fine - $id_inizio + 1;
$riduci_font = "";
$lung_cognome = strlen($cognome);
$lung_freccia = 0;
if ($id_fine_prenota > $id_data_fine_tab or $id_inizio_prenota < $id_data_inizio_tab) $lung_freccia = 3;
$lung_non_ridotta = (12+$aggiunta_tronca)*$colonne - $lung_freccia;
if ($lung_cognome > $lung_non_ridotta) $riduci_font = "SI";
$lung_non_tronca = (15+$aggiunta_tronca)*$colonne;
if ($lung_freccia == 3) $lung_non_tronca = $lung_non_tronca - 1;
if ($lung_cognome > ($lung_non_tronca+1)) $cognome = substr($cognome,0,$lung_non_tronca).".";
echo "<td";
#if ($colore) { echo " bgcolor =\"$colore\""; }
$colonne_span = $colonne * 8;
echo" align=\"center\" colspan=\"$colonne_span\">";
if ($id_inizio_prenota < $id_data_inizio_tab) { echo "<- "; }
echo "<font size=-2>
<a href=\"modifica_prenota.php?id_prenota=$id_prenota&anno=$anno&mese=$mese\">$cognome</a>
</font>";
if ($id_fine_prenota > $id_data_fine_tab) { echo " ->"; }
echo "</td>
";
$num2 = $num2 + $colonne - 1;
} # fine if ($esiste == 1)
else {
for ($num3 = 0 ; $num3 < 8 ; $num3 = $num3 + 1) {
echo "<td";
if ($num3 == 0 or $num3 == 7) { echo " bgcolor =\"#cccccc\""; }
echo ">&nbsp;</td>
";
} # fine for $num3
} # fine else if ($esiste == 1)
} # fine for $num2

if ($num1 < $num_appartamenti) {
echo "<td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
else echo "<font size=-1>";
echo "$id_appartamento</font></td>";
} # fine if ($num1 < $num_appartamenti)
else {
echo "<td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
else echo "<font size=-1>";
echo "<font color=\"red\">$id_appartamento</font></font></td>";
} # fine else if ($num1 < $num_appartamenti)
echo "</tr>";

} # fine for $num1

echo "</table>";

} # fine for $mese2


unlock_tabelle($tabelle_lock);

echo "<center>
<form method=\"post\" action=\"inizio.php\">";
if ($mese != 1) {
$mese_prec = $mese - 1;
echo "<a href=\"tabella2.php?anno=$anno&mese=$mese_prec\"><--</a>&nbsp;&nbsp;&nbsp;&nbsp;";
} # fine if ($mese != 1)
echo "<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"".mex("Torna al men principale",$pag)."\">";
if ($mese != 25) {
$mese_succ = $mese + 1;
echo "&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"tabella2.php?anno=$anno&mese=$mese_succ\">--></a>";
} # fine if ($mese != 12)
echo "</form>
<form method=\"post\" action=\"tabella.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"mese\" value=\"$mese\">
<input type=\"submit\" name=\"tab2\" value=\"".mex("Visualizza la tabella normale",$pag)."\">
</form>
<form method=\"post\" action=\"tabella2.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"mese\" value=\"$mese\">
<input type=\"submit\" name=\"tutti_mesi\" value=\"".mex("Visualizza tutti i mesi",$pag)."\">
</form></center>";



?>

</body>
</html>
